***************
Un Tour Guiado
***************

Esta sección es un tour guiado de las opciones disponibles en Sage.
Para muchos más ejemplos, véase "Construcciones En Sage", con la cual se intenta
responder a la pregunta general "¿Cómo hago para construir ...?". Véase también
el "Manual De Referencia De Sage", el cual tiene miles de ejemplos.
Observa también que puedes trabajar interactivamente con este tour en el
notebook de Sage haciendo click en el enlace ``Help``.

(Si estás viendo el tutorial en el notebook de Sage,
presiona ``shift-enter`` para evaluar cualquier celda de entrada de datos.
Incluso puedes editar la entrada de datos antes de presionar ``shift-enter``.
En algunas Macs tendrías que presionar ``shift-return`` en lugar de ``shift-enter``.)

.. toctree::

   tour_assignment
   tour_help
   tour_algebra
   tour_rings
   tour_linalg
   tour_polynomial
   tour_groups
   tour_numtheory
